<?php
/*
	Plugin Name: BegetByMe Offer Publisher
	Plugin URI: http://www.beget.com                                                                                                                                                                             
	Version: 0.1b                                                                                                                                                                                                 
	Author: Beget                                                                                                                                                                                                
	Description: Plugin to pull in offers as posts.
*/


define('BBM_PLUGIN_DIRECTORY', 'beget-by-me');
define('BBM_REGISTER_URL', 'http://<subdomain>.begetbyme.com/feeds/register');
define('BBM_PULL_URL', 'http://<subdomain>.begetbyme.com/feeds/pull');

add_action('plugins_loaded', 'bbm_check_feeds');
add_action('admin_menu', 'bbm_create_menu');
add_action('admin_init', 'bbm_register_settings');
add_action('admin_head', 'bbm_admin_head');

register_activation_hook(__FILE__, 'bbm_activate');
register_deactivation_hook(__FILE__, 'bbm_deactivate');
register_uninstall_hook(__FILE__, 'bbm_uninstall');

add_filter('post_link', 'bbm_permalink');

function bbm_check_feeds(){
	$registrationId = get_option('bbm_registration_id');
	if(isset($_REQUEST['update_begetbyme']) && $registrationId){
		
		$pullUrl = str_replace('<subdomain>', get_option('bbm_subdomain'), BBM_PULL_URL);
		
		$posts = bbm_get_posts($pullUrl); //unserialize($_POST['post']);
		if($posts && count($posts))
		{
			foreach($posts as $post)
			{
				bbm_insert_post($post);
			}
		}
		exit();
	}
}

function bbm_insert_post($post)
{
	$guid = $post['guid'];

	global $wpdb;
	$guidCheck = $wpdb->get_results('SELECT ID FROM wp_posts where guid = \'' . buildGuid($guid) . '\'');
	
	$oldPost = false;
	if(count($guidCheck)){
		$oldPost = true;
	}
	
	if(!$oldPost)
	{
		$post['guid'] = buildGuid($guid);
		$postUser = $post['post_author'];
		$users = get_users();
		foreach($users as $user)
		{
			if($user->user_nicename == $postUser)
			{
				$post['post_author'] = $user->ID;
				break;
			}
		}
		if($post['post_author'] == $postUser)
		{
			$post['post_author'] = wp_insert_user
			(
					array
					(
							'user_nicename'=>$postUser,
							'display_name'=>$postUser,
							'user_login'=>$postUser,
							'role'=>'author',
							'user_url'=>$post['user_url']
					)
			);
		}
		unset($post['user_url']);
		$postId = wp_insert_post( $post, $wp_error );
		if(!empty($post['permalink_url'])){
			update_post_meta($postId, 'deal_url', $post['permalink_url']);
		}
	}
}

function bbm_get_posts($pullUrl)
{
	$dealResponse = wp_remote_get($pullUrl);
	if(is_wp_error($dealResponse)){
		return false;
	}
	return unserialize(wp_remote_retrieve_body($dealResponse));
}

function bbm_admin_head() {
	echo '<link rel="stylesheet" type="text/css" href="' .plugins_url('/css/bbm-admin.css', __FILE__). '" />',
		'<script type="text/javascript" src="' . plugins_url('/js/bbm-admin.js', __FILE__) . '"></script>';
}


function bbm_create_menu(){
	add_menu_page(
			__('BegetByMe', ''),
			__('BegetByMe', ''),
			0,
			BBM_PLUGIN_DIRECTORY.'/bbm_settings.php',
			'',
			plugins_url('/images/bbm-icon.png', __FILE__)
	);
}

function bbm_update_permalink($permalink){
	return $permalink;
}

function bbm_register_settings(){
	register_setting( 'bbm-settings-group', 'bbm_subdomain' );
	register_setting( 'bbm-settings-group', 'bbm_registration_id' );
}

function bbm_activate(){
	add_option('bbm_subdomain', '');
	add_option('bbm_registration_id', '');
}

function bbm_deactivate(){
	
}

function bbm_uninstall(){
	delete_option('bbm_subdomain');
	delete_option('bbm_registration_id');
}

function bbm_permalink ($permalink = '', $post = null, $leavename = false) {
	global $id;

	if (is_object($post) and isset($post->ID) and !empty($post->ID)) :
		// Use the post ID we've been provided with.
		$postId = $post->ID;
	elseif (is_string($permalink) and strlen($permalink) > 0) :
		// Map this permalink to a post ID so we can get the correct
		// permalink even outside of the Post Loop. Props Björn.
		$postId = url_to_postid($permalink);
	else :
		// If the permalink string is empty but Post Loop context
		// provides an id.
		$postId = $id;
	endif;
	
	$uri = get_post_custom_values('deal_url', $id);
	$permalink = ((strlen($uri[0]) > 0) ? $uri[0] : $permalink);
	return $permalink;
}

function buildGuid($guid)
{
	return get_option('siteurl') . '/?guid=' . $guid;
}
